@@ -4,9 +4,6 @@
 
 set -e
 
-export TAR_OPTIONS='--owner root --group root --mode a+rX'
-export GZIP_OPTIONS='-9n'
-
 BRANCH="master"
 MJ_COMMITS="https://github.com/mathjax/mathjax-docs/commits/$BRANCH"
 MJ_TARBALL="https://github.com/mathjax/mathjax-docs/archive/$BRANCH.tar.gz"
@@ -27,7 +24,7 @@ VERSION="$BASEVERSION+$DATE"
 FILENAME="mathjax-docs_$VERSION.orig.tar.gz"
 
 mv "MathJax-docs-$BRANCH" "mathjax-docs-$VERSION"
-GZIP=-n tar --sort=name --mode=u=rwX,go=rX -czf "$pwd/$FILENAME" "mathjax-docs-$VERSION"
+tar --sort=name --owner=root --group=root --mode=u=rwX,go=rX -I 'gzip -n' -cf "$pwd/$FILENAME" "mathjax-docs-$VERSION"
 cd ..
 rm -Rf "$tmpdir"
 
